@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = v0.0.4;
+our $VERSION = v0.0.5;
 
 my $CRLF = "\r\n";
 
@@ -180,52 +180,48 @@ v0.0.3
 
 =head1 SINOPSIS
 	
+	# Make datafiles for test:
 	`echo "Simple text." > /tmp/file.txt`;
-	$?	#  0
 	`gzip < /tmp/file.txt > /tmp/file.gz`;
-	$?	#  0
 	
 	use Multipart::Encoder;
 	
 	my $multipart = Multipart::Encoder->new(
-		x=>1,
-		file_name => \"/tmp/file.txt",
-		y=>[
-			"Content-Type" => "text/json",
-			name => 'my-name',
-			filename => 'my-filename',
-			_ => '{"count": 666}',
-			'Any-Header' => 123,
-		],
-		z => {
-			_ => \'/tmp/file.gz',
-			'Any-Header' => 123,
-		}
+	    x=>1,
+	    file_name => \"/tmp/file.txt",
+	    y=>[
+	        "Content-Type" => "text/json",
+	        name => 'my-name',
+	        filename => 'my-filename',
+	        _ => '{"count": 666}',
+	        'Any-Header' => 123,
+	    ],
+	    z => {
+	        _ => \'/tmp/file.gz',
+	        'Any-Header' => 123,
+	    }
 	)->buffer_size(2048)->boundary("xYzZY");
 	
 	my $str = $multipart->as_string;
 	
-	utf8::is_utf8($str)			## ""
+	utf8::is_utf8($str)            ## ""
 	
-	$str 						#~ \r\n--xYzZY--\r\n\z
+	$str                           #~ \r\n--xYzZY--\r\n\z
 	
 	$multipart->to("/tmp/file.form-data");
 	
 	open my $f, "<", "/tmp/file.form-data"; binmode $f; read $f, my $buf, -s $f; close $f;
+	$buf                           ## $str
 	
-	utf8::is_utf8($buf)			## ""
-	
-	$buf						## $str
-	
-	$multipart->to(\*STDOUT);	##>> $str
+	$multipart->to(\*STDOUT);      ##>> $str
 	
 =head1 DESCRIPTION
 
-The encoder in 'multipart/form-data' is not represented in perl libraries. It is only used as part of other libraries, for example, CL<HTTP::Tiny::Multipart>.
+The encoder in 'multipart/form-data' is not represented in perl libraries. It is only used as part of other libraries, for example, C<HTTP::Tiny::Multipart>.
 
 But there is no such library for C<AnyEvent::HTTP>.
 
-The only module CL<HTTP::Body::Builder::MultiPart> does not allow adding a file as a string to a B<multipart>.
+The only module C<HTTP::Body::Builder::MultiPart> does not allow adding a file as a string to a B<multipart>.
 
 =head1 INSTALL
 
@@ -239,39 +235,39 @@ Constructor.
 	
 	my $multipart1 = Multipart::Encoder->new;
 	my $multipart2 = $multipart1->new;
-	$multipart2	##!= $multipart1
+	$multipart2    ##!= $multipart1
 	
-	ref Multipart::Encoder::new(0)	# 0
+	ref Multipart::Encoder::new(0)    # 0
 	
 B<Return> new object.
 
 Arguments is a params for serialize to multipart-format.
 	
-	Multipart::Encoder->new(x=>123)->as_string    #~ 123	
+	Multipart::Encoder->new(x=>123)->as_string    #~ 123    
 	
 =head2 content_type
 	
-	$multipart->content_type	# multipart/form-data
+	$multipart->content_type    # multipart/form-data
 	
 =head2 buffer_size
 
 Set or get buffer size. Buffer using for write to file.
 	
-	$multipart->buffer_size(1024)->buffer_size		# 1024
+	$multipart->buffer_size(1024)->buffer_size        # 1024
 	
 Default buffer size:
 	
-	Multipart::Encoder->new->buffer_size			# 2048
+	Multipart::Encoder->new->buffer_size            # 2048
 	
 =head2 boundary
 
 Boundary is a separator before params in multipart-data.
 	
-	$multipart->boundary("XYZooo")->boundary		# XYZooo
+	$multipart->boundary("XYZooo")->boundary        # XYZooo
 	
 Default boundary:
 	
-	Multipart::Encoder->new->boundary				# xYzZY
+	Multipart::Encoder->new->boundary                # xYzZY
 	
 =head2 as_string
 
@@ -292,7 +288,7 @@ Argument for C<to>  must by path or filehandle.
 	
 If file not open raise the die.
 	
-	$multipart->to("/")		#@ ~ Not open file `/`. Is a directory
+	$multipart->to("/")        #@ ~ Not open file `/`. Is a directory
 	
 =head1 PARAMS
 
@@ -300,15 +296,15 @@ Param types is file and string.
 
 =head2 String param type
 	
-	Multipart::Encoder->new(x=>"Simple string")->as_string	#~ Simple string
+	Multipart::Encoder->new(x=>"Simple string")->as_string    #~ Simple string
 	
 With headers:
 	
 	my $str = Multipart::Encoder->new(
-		x => {
-			_ => "Simple string",
-			header => 123,
-		},
+	    x => {
+	        _ => "Simple string",
+	        header => 123,
+	    },
 	)->as_string;
 	
 	$str #~ Simple string
@@ -316,15 +312,15 @@ With headers:
 	
 Header B<Content-Disposition> added automically.
 	
-	Multipart::Encoder->new(x=>"Simple string")->as_string	#~ Content-Disposition: form-data; name="x"
+	Multipart::Encoder->new(x=>"Simple string")->as_string    #~ Content-Disposition: form-data; name="x"
 	
 Name in B<Content-Disposition> set as key, or name-header:
 	
 	my $str = Multipart::Encoder->new(
-		x => {
-			_ => "Simple string",
-			name => "xyz",
-		},
+	    x => {
+	        _ => "Simple string",
+	        name => "xyz",
+	    },
 	)->as_string;
 	
 	$str #~ Content-Disposition: form-data; name="xyz"
@@ -332,10 +328,10 @@ Name in B<Content-Disposition> set as key, or name-header:
 If need filename in B<Content-Disposition>, add it:
 	
 	my $str = Multipart::Encoder->new(
-		0 => {
-			_ => "Simple string",
-			filename => "xyz.tgz",
-		},
+	    0 => {
+	        _ => "Simple string",
+	        filename => "xyz.tgz",
+	    },
 	)->as_string;
 	
 	$str #~ Content-Disposition: form-data; name="0"; filename="xyz.tgz"
@@ -343,10 +339,10 @@ If need filename in B<Content-Disposition>, add it:
 If B<Content-Disposition> is, then it use once.
 	
 	my $str = Multipart::Encoder->new(
-		x => {
-			_ => "Simple string",
-			'content-disposition' => "form-data; name=\"z\"; filename=\"xyz\"",
-		},
+	    x => {
+	        _ => "Simple string",
+	        'content-disposition' => "form-data; name=\"z\"; filename=\"xyz\"",
+	    },
 	)->as_string;
 	
 	$str #~ content-disposition: form-data; name="z"; filename="xyz"
@@ -357,19 +353,19 @@ Header B<Content-Disposition> added automically.
 	
 	open my $f, ">/tmp/0"; close $f;
 	
-	Multipart::Encoder->new(x=>\"/tmp/0")->as_string	#~ Content-Disposition: form-data; name="x"; filename="0"
+	Multipart::Encoder->new(x=>\"/tmp/0")->as_string    #~ Content-Disposition: form-data; name="x"; filename="0"
 	
 Header B<Content-Type> added automically.
 	
-	Multipart::Encoder->new(x=>\"/tmp/file.gz")->as_string	#~ Content-Type: application/x-gzip; charset=binary
+	Multipart::Encoder->new(x=>\"/tmp/file.gz")->as_string    #~ Content-Type: application/x-gzip; charset=binary
 	
 But if it is, then used once.
 	
 	my $str = Multipart::Encoder->new(
-		x => [
-			_ => \"/tmp/file.gz",
-			'content-type' => 'text/plain',
-		]
+	    x => [
+	        _ => \"/tmp/file.gz",
+	        'content-type' => 'text/plain',
+	    ]
 	)->as_string;
 	
 	$str #~ content-type: text/plain
@@ -378,10 +374,10 @@ But if it is, then used once.
 Name in B<Content-Disposition> set as key, or name-header:
 	
 	my $str = Multipart::Encoder->new(
-		x => {
-			_ => \"/tmp/file.txt",
-			name => "xyz",
-		},
+	    x => {
+	        _ => \"/tmp/file.txt",
+	        name => "xyz",
+	    },
 	)->as_string;
 	
 	$str #~ Content-Disposition: form-data; name="xyz"; filename="file.txt"
@@ -389,10 +385,10 @@ Name in B<Content-Disposition> set as key, or name-header:
 If need filename in B<Content-Disposition>, add it:
 	
 	my $str = Multipart::Encoder->new(
-		0 => {
-			_ => \"/tmp/file.txt",
-			filename => "xyz.tgz",
-		},
+	    0 => {
+	        _ => \"/tmp/file.txt",
+	        filename => "xyz.tgz",
+	    },
 	)->as_string;
 	
 	$str #~ Content-Disposition: form-data; name="0"; filename="xyz.tgz"
@@ -400,10 +396,10 @@ If need filename in B<Content-Disposition>, add it:
 If B<Content-Disposition> is, then it use once.
 	
 	my $str = Multipart::Encoder->new(
-		x => [
-			_ => \"/tmp/file.txt",
-			'content-disposition' => "form-data; name=\"z\"; filename=\"xyz\"",
-		],
+	    x => [
+	        _ => \"/tmp/file.txt",
+	        'content-disposition' => "form-data; name=\"z\"; filename=\"xyz\"",
+	    ],
 	)->as_string;
 	
 	$str #~ content-disposition: form-data; name="z"; filename="xyz"
@@ -411,7 +407,7 @@ If B<Content-Disposition> is, then it use once.
 Big file.
 	
 	open my $f, ">", "/tmp/bigfile"; binmode $f; print $f 0 x 65534; close $f;
-	Multipart::Encoder->new(x=>\"/tmp/bigfile")->as_string	#~ \n0{65534}\r
+	Multipart::Encoder->new(x=>\"/tmp/bigfile")->as_string    #~ \n0{65534}\r
 	
 Raise if not open file.
 	
@@ -422,9 +418,9 @@ Raise if not open file.
 
 =over
 
-=item * CLL<HTTP::Tiny::Multipart>
+=item * C<HTTP::Tiny::Multipart>
 
-=item * CLL<HTTP::Body::Builder::MultiPart>
+=item * C<HTTP::Body::Builder::MultiPart>
 
 =back
 
@@ -436,4 +432,4 @@ This library is free software; you can redistribute it and/or modify it under th
 
 =head1 AUTHOR
 
-Yaroslav O. Kosmina L<mailto:darviarush@mail.ru>
+Yaroslav O. Kosmina L<mailto:dart@cpan.org>
